SystemOrganization addCategory: #ConfigurationOfSeasideRest!

Object subclass: #ConfigurationOfSeasideRest
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeasideRest'!

!ConfigurationOfSeasideRest class methodsFor: 'private' stamp: 'pmm 3/18/2011 21:27'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [ :reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository ]! !

!ConfigurationOfSeasideRest class methodsFor: 'private' stamp: 'pmm 3/18/2011 21:27'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk globals at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk globals at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk globals at: #Gofer ifPresent: [ :goferClass |
						| gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk globals at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSeasideRest class methodsFor: 'metacello tool support' stamp: 'pmm 3/18/2011 21:27'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSeasideRest class methodsFor: 'metacello tool support' stamp: 'pmm 3/18/2011 21:27'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSeasideRest class methodsFor: 'loading' stamp: 'pmm 3/18/2011 21:27'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfSeasideRest class methodsFor: 'metacello tool support' stamp: 'pmm 3/18/2011 21:27'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSeasideRest class methodsFor: 'accessing' stamp: 'pmm 3/18/2011 21:27'!
project

	^self new project! !

!ConfigurationOfSeasideRest methodsFor: 'baselines' stamp: 'topa 3/24/2011 12:11'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30Addons'.

		"We need Seaside"
		spec
			project: 'Seaside' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Seaside-Core');
					file: 'ConfigurationOfSeaside30';
					repository: 'http://www.squeaksource.com/MetacelloRepository'].

		"Just the fact it exists"
		spec package: 'Seaside-REST-Core' with: [spec requires: 'Seaside'].

		"Tests require existence of Core"
		spec package: 'Seaside-Tests-REST-Core' with: [spec requires: 'Seaside-REST-Core'].
		
		spec
			group: 'default' with: #('Seaside-REST-Core');
			group: 'Tests' with: #('Seaside-Tests-REST-Core');
			yourself].
		
	spec for: #squeakCommon do: [
		"Include Pharo packages when on Pharo or Squeak"
		spec
			package: 'Seaside-REST-Core' with: [spec includes: #('Seaside-Pharo-REST-Core')];
			package: 'Seaside-Pharo-REST-Core' with: [spec requires: #('Seaside-REST-Core')];
			yourself].
		
	spec for: #gemstone do: [
		"Include GemStone packages when on GemStone"
		spec
			package: 'Seaside-REST-Core' with: [spec includes: #('Seaside-GemStone-REST-Core')];
			package: 'Seaside-GemStone-REST-Core' with: [spec requires: #('Seaside-REST-Core')];
			yourself].
! !

!ConfigurationOfSeasideRest methodsFor: 'baselines' stamp: 'DiegoLont 9/2/2013 11:59'!
baseline21: spec
	<version: '0.21-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.smalltalkhub.com/mc/Seaside/Seaside30Addons/main'.

		"We need Seaside"
		spec
			project: 'Seaside' with: [
				spec
					className: 'ConfigurationOfSeaside3';
					loads: #('Seaside-Core');
					file: 'ConfigurationOfSeaside3';
					repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main'];
			project: 'Seaside Tests' copyFrom: 'Seaside' with: [
				spec loads: #('Seaside-Tests-Core') ].

		"Just the fact it exists"
		spec package: 'Seaside-REST-Core' with: [spec requires: 'Seaside'].

		"Tests require existence of Core"
		spec package: 'Seaside-Tests-REST-Core' with: [
			spec requires: #('Seaside-REST-Core' 'Seaside Tests')].
		
		spec
			group: 'default' with: #('Seaside-REST-Core');
			group: 'Tests' with: #('Seaside-Tests-REST-Core');
			yourself].
		
	spec for: #squeakCommon do: [
		"Include Pharo packages when on Pharo or Squeak"
		spec
			package: 'Seaside-REST-Core' with: [spec includes: #('Seaside-Pharo-REST-Core')];
			package: 'Seaside-Pharo-REST-Core' with: [spec requires: #('Seaside-REST-Core')];
			yourself].
		
	spec for: #gemstone do: [
		"Include GemStone packages when on GemStone"
		spec
			package: 'Seaside-REST-Core' with: [spec includes: #('Seaside-GemStone-REST-Core')];
			package: 'Seaside-GemStone-REST-Core' with: [spec requires: #('Seaside-REST-Core')];
			yourself].
! !

!ConfigurationOfSeasideRest methodsFor: 'symbolic versions' stamp: 'dkh 05/18/2011 15:08'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '0.21-baseline'.
! !

!ConfigurationOfSeasideRest methodsFor: 'symbolic versions' stamp: 'NickAger 3/25/2012 03:01'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfSeasideRest methodsFor: 'accessing' stamp: 'pmm 3/18/2011 21:27'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfSeasideRest methodsFor: 'symbolic versions' stamp: 'EstebanLorenzano 9/23/2013 12:43'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.22'.! !

!ConfigurationOfSeasideRest methodsFor: 'versions' stamp: 'dkh 05/18/2011 14:55'!
version017: spec
	<version: '0.17' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec 
			project: 'Seaside' with: '3.0.4'.
		spec 
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-pmm.17';
			package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.4';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-pmm.11';
			package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-DaleHenrichs.1'.
	]
! !

!ConfigurationOfSeasideRest methodsFor: 'versions' stamp: 'dkh 05/18/2011 14:55'!
version018: spec
	<version: '0.18' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec 
			project: 'Seaside' with: '3.0.4'.
		spec 
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-pmm.18';
			package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.4';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-pmm.12';
			package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-DaleHenrichs.1'.
	]
! !

!ConfigurationOfSeasideRest methodsFor: 'versions' stamp: 'topa 3/24/2011 12:19'!
version019: spec
	<version: '0.19' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Require Seaside and split for the platforms'.
		spec author: 'topa'.
		spec timestamp: '3/24/2011 12:12'.

		spec 
			project: 'Seaside' with: '3.0.4';
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-pmm.18';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-pmm.12'].

	spec for: #'squeakCommon' do: [
		spec
			package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.4'].
		
	spec for: #'gemstone' do: [
		spec 
			package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-DaleHenrichs.1'].
! !

!ConfigurationOfSeasideRest methodsFor: 'versions' stamp: 'pmm 4/7/2011 19:58'!
version020: spec
	<version: '0.20' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Update GemStone implemenation'.
		spec author: 'pmm'.
		spec timestamp: '4/7/2011 19:58'.

		spec 
			project: 'Seaside' with: '3.0.4';
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-pmm.18';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-pmm.12'].

	spec for: #'squeakCommon' do: [
		spec
			package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.4'].
		
	spec for: #'gemstone' do: [
		spec 
			package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-topa.2'].
! !

!ConfigurationOfSeasideRest methodsFor: 'versions' stamp: 'dkh 05/18/2011 15:45'!
version021: spec
	<version: '0.21' imports: #('0.21-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.21 (dkh.6):
- open 0.21 for development
- GemStone doesn''t like #sort: being sent to a SortedCollection ... so changed code in WARouteContainer>>routeForElements:parameters:contentType:accept:ifAbsent: to be more GemStone friendly ... my arm can be twisted:) tho
0.21 (dkh.7):
- tests all passing for GemStone (1 bugfix and 1 testfix)'.
		spec author: 'dkh'.
		spec timestamp: '05/18/2011 15:45:06'.
		spec 
			project: 'Seaside' with: '3.0.4';
			project: 'Seaside Tests' with: '3.0.4'.
		spec 
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-dkh.20';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-dkh.13'. ].

	spec for: #'squeakCommon' do: [
		spec package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.4'. ].

	spec for: #'gemstone' do: [
		spec package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-topa.2'. ].
! !

!ConfigurationOfSeasideRest methodsFor: 'versions' stamp: 'NickAger 3/24/2012 21:32'!
version022: spec
	<version: '0.22' imports: #('0.21-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.22 (dkh.8):
- open 0.22 for development
- pick up latest packages
0.22 (dkh.9):
- fix a GemStone portability issue in WARouteBuilder class>>createRoutesFrom:to:'.
		spec author: 'dkh'.
		spec timestamp: '10/07/2011 16:48:20'.
		spec 
			project: 'Seaside' with: #stable;
			project: 'Seaside Tests' with: #stable.
		spec 
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-dkh.39';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-pmm.22'. ].

	spec for: #'squeakCommon' do: [
		spec package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-lr.6'. ].

	spec for: #'gemstone' do: [
		spec package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-topa.2'. ].
! !

!ConfigurationOfSeasideRest methodsFor: 'versions' stamp: 'EstebanLorenzano 9/25/2013 12:38'!
version022s31: spec
	<version: '0.22-Seaside31' imports: #('0.21-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Uses Seaside 3.1'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '25 September 2013 12:38:04 pm'.
		spec 
			project: 'Seaside' with: '3.1.0';
			project: 'Seaside Tests' with: '3.1.0'.
		spec 
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-dkh.39';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-pmm.22'. ].

	spec for: #'squeakCommon' do: [
		spec package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-lr.6'. ].

	spec for: #'gemstone' do: [
		spec package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-topa.2'. ].
! !
